\name{grin.gsets}
\alias{grin.gsets}
 \title{gene set analysis}
 \description{Perform GRIN analysis for overlap of lesions with pre-defined gene-sets}
\usage{
grin.gsets (lesion.locs, gene.locs = hg19.gene.annotation.data, 
    gset.data = KEGG.gset.data, chrom.sizes = hg19.chrom.sizes.data, 
    edge.adjustment = F, remove.dups = T, min.nhits.report = 1, 
    order.results = T, quiet = F, compute.q = T) 
}
 \arguments{
 \item{lesion.locs}{data.frame with one row per lesion, columns for subj.ID, chrom, loc.start, loc.end}
 \item{gene.locs}{data.frame with one row per gene, columns for gene.id, gene.label, chrom, loc.start, loc.end. The default is hg19.gene.annotation.data}
 \item{gset.data}{data.frame with one row per assignment of gene to gene-set, columns for gset.id, gset.label, and gene.id.The default is KEGG.gset.data}
 \item{chrom.sizes}{data.frame with one row per chromosome, columns for chrom and size. The default is hg19.chrom.sizes.data}
 \item{edge.adjustment}{indicates whether to circularize chromosomes to eliminate edge effects}
 \item{remove.dups}{indicates whether to remove duplicate entries from gene.locs and gset.data before analysis}
 \item{min.nhits.report}{minimum number of hits to include in the report}
 \item{order.results}{indicates whether to order results by cohort.max.pvalue in ascending order}
 \item{quiet}{indicates whether to be quiet while running, if FALSE it will output progress messages}
 \item{compute.q}{used to compute the q value:the smoothed local False Discovery Rate estimates}
 }
 \examples{
 data(ETP.lesion.data)
 data(hg18.gene.annotation.data)
 data(hg18.chrom.sizes.data)
 data(KEGG.gset.data)
 #gset.res<-grin.gsets(ETP.lesion.data, hg18.gene.annotation.data, KEGG.gset.data, hg18.chrom.sizes.data) #commented out example
 }
 \references{Pounds S, Cheng C, Li, S, Liu Z, Zhang J, Mullighan C(2013) Genomic Random Interval Models for Statistical Analysis of Genomic Lesion Data. Bioinformatics.


             Pounds and Cheng (2006) Robust estimation of the false discovery rate. Bioinformatics 22: 1979-87.}
 \value{a list with the following main components:
            \item{gset.source}{lists the source of the gene set definition}
            \item{gset.id}{lists the identifier of the gene set}
            \item{gset.label}{lists the label of the gene set}
            \item{ngenes.gset}{gives the number of genes assigned to the gene set}
            \item{gset.gene.ids}{lists the genes Entry ID(NCBI) assigned to the gene set}
            \item{ngenes.with.locus.data}{gives the number of genes in the set that were successfully matched to the gene location data}
            \item{all.genes.matched}{indicates (TRUE/FALSE) whether all genes in the set were successfully matched to the gene location data}
            \item{n.overlaps}{total number of lesion loci that overlap the locus of the gene set}
            \item{p.overlaps}{ p-value for n.overlaps from the convolution model}
            \item{q.overlaps}{false discovery rate for p.overlaps}
            \item{n.subjects}{lists the number of subjects with a lesion overlapping the interval.}
            \item{p.subjects}{p-value for n.subjects from the convolution model}
            \item{q.subjects}{false discovery rate for p.subjects} 
            \item{n.lesions}{the total number of lesions that overlap at least one gene in the gene set}
            \item{p.lesions}{p-value for n.lesion from the convolution model}
            \item{q.lesions}{false discovery rate for p.lesions}  
           }
