\name{grin.genes}
\alias{grin.genes}
 \title{gene analysis}
 \description{perform GRIN analysis for individual genes}
\usage{
grin.genes (lesion.locs, gene.locs = hg19.gene.annotation.data, 
    chrom.sizes = hg19.chrom.sizes.data, compute.q = T, edge.adjustment = T) 
}
 \arguments{
 \item{lesion.locs}{data.frame with one row per lesion, required columns are subj.ID, chrom, loc.start, and loc.end}
 \item{gene.locs}{data.frame with one row per gene, columns for gene.id, gene.label, chrom, loc.start, loc.end. The default is hg19.gene.annotation.data}
 \item{chrom.sizes}{data.frame with one row per chromosome, required columns are chrom & size. The default is hg19.chrom.sizes.data}
 \item{compute.q}{used to compute the q value:the smoothed local False Discovery Rate estimates}
 \item{edge.adjustment}{indicates whether to circularize chromosomes to eliminate edge effects} 
 }
 \examples{
 data(ETP.lesion.data)
 data(hg18.gene.annotation.data)
 data(hg18.chrom.sizes.data)
 #gene.res<-grin.genes(ETP.lesion.data, hg18.gene.annotation.data, hg18.chrom.sizes.data)
 }
 \references{Pounds S, Cheng C, Li, S, Liu Z, Zhang J, Mullighan C(2013) Genomic Random Interval Models for Statistical Analysis of Genomic Lesion Data. Bioinformatics.


             Pounds and Cheng (2006) Robust estimation of the false discovery rate. Bioinformatics 22: 1979-87.}
 \value{a list with the following components:
            \item{chrom}{chrom number}
            \item{gene.id}{NCBI Entry gene ID}
            \item{gene.label}{gene name}
            \item{loc.start}{location of start of each gene }
            \item{loc.end}{location of end of each gene}
            \item{n.overlaps}{total number of lesion loci that overlap the locus of the gene}
            \item{p.overlaps}{ p-value for n.overlaps from the convolution model}
            \item{q.overlaps}{false discovery rate for p.overlaps}
            \item{n.subjects}{lists the number of subjects with a lesion overlapping the interval.}
            \item{p.subjects}{p-value for n.subjects from the convolution model}
            \item{q.subjects}{false discovery rate for p.subjects} 
           }
