\name{grin.genome}
\alias{grin.genome}
 \title{grin.gemome}
 \description{Perform GRIN analysis for genomic interval loci defined by lesion and chromosome endpoints}
\usage{
grin.genome (lesion.locs, gene.locs = hg19.gene.annotation.data, 
    chrom.sizes = hg19.chrom.sizes.data, edge.adjustment = T, 
    compute.q = T) 
}
 \arguments{
 \item{lesion.locs}{data.frame with one row per lesion, required columns are subj.ID, chrom, loc.start, loc.end}
 \item{gene.locs}{data.frame with one row per gene, columns for gene.id, gene.label, chrom, loc.start, loc.end. The default is hg19.gene.annotation.data }
 \item{chrom.sizes}{data.frame with one row per chromosome, required columns are chrom & size. The default is hg19.chrom.sizes.data }
 \item{edge.adjustment}{indicates whether to circularize chromosomes to eliminate edge effects}
 \item{compute.q}{used to compute the q value:the smoothed local False Discovery Rate estimates}
 }
 \examples{
 data(ETP.lesion.data)
 data(hg18.gene.annotation.data)
 data(hg18.chrom.sizes.data)
 #genome.res<-grin.genome(ETP.lesion.data, hg18.gene.annotation.data,hg18.chrom.sizes.data)
 }
 \references{Pounds S, Cheng C, Li, S, Liu Z, Zhang J, Mullighan C(2013) Genomic Random Interval Models for Statistical Analysis of Genomic Lesion Data. Bioinformatics.


             Pounds and Cheng (2006) Robust estimation of the false discovery rate. Bioinformatics 22: 1979-87.}
 \value{a list with the following components:
            \item{interval.id}{gives a numeric identifier to the interval}
            \item{chrom}{chrom number}
            \item{loc.start}{location of start of each gene}
            \item{loc.end}{location of end of each gene}
            \item{size}{gives the size of the interval in base pairs}
            \item{n.gene}{gives the number of genes in the segment}
            \item{gene.list}{lists the gene names in the segment}
            \item{n.overlaps}{total number of lesion loci that overlap the locus of the gene}
            \item{p.overlaps}{ p-value for n.overlaps from the convolution model}
            \item{q.overlaps}{false discovery rate for p.overlaps}
            \item{n.subjects}{lists the number of subjects with a lesion overlapping the interval}
            \item{p.subjects}{p-value for n.subjects from the convolution model}
            \item{q.subjects}{false discovery rate for p.subjects} 
           }
